==> vue-cell-3.22.0.tgz: package/lib/index.js <==
import { t } from '@opentinyvue/vue-locale';
import { renderless, api } from '@opentinyvue/vue-renderless/cell/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { IconChevronRight } from '@opentinyvue/vue-icon';
import { openBlock, createElementBlock, normalizeClass, createTextVNode, toDisplayString, renderSlot, createBlock, resolveDynamicComponent, createCommentVNode } from 'vue';

function _createForOfIteratorHelperLoose(r, e) {
  var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"];
  if (t) return (t = t.call(r)).next.bind(t);
  if (Array.isArray(r) || (t = _unsupportedIterableToArray(r)) || e && r && "number" == typeof r.length) {
    t && (r = t);
    var o = 0;
    return function() {
      return o >= r.length ? { done: true } : { done: false, value: r[o++] };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _unsupportedIterableToArray(r, a) {
  if (r) {
    if ("string" == typeof r) return _arrayLikeToArray(r, a);
    var t = {}.toString.call(r).slice(8, -1);
    return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0;
  }
}
function _arrayLikeToArray(r, a) {
  (null == a || a > r.length) && (a = r.length);
  for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e];
  return n;
}
var _export_sfc = function _export_sfc2(sfc, props) {
  var target = sfc.__vccOpts || sfc;
  for (var _iterator = _createForOfIteratorHelperLoose(props), _step; !(_step = _iterator()).done; ) {
    var _step$value = _step.value, key = _step$value[0], val = _step$value[1];
    target[key] = val;
  }
  return target;
};

var _sfc_main = defineComponent({
  name: $prefix + "Cell",
  componentName: "Cell",
  props: {
    placeholder: {
      type: String,
      default: t("ui.cell.placeholder")
    },
    disabled: {
      type: Boolean,
      default: false
    },
    data: {
      type: String,
      default: ""
    },
    icon: {
      type: [Object, String],
      default: function _default() {
        return IconChevronRight();
      }
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var _hoisted_1 = {
  key: 0,
  "data-tag": "tiny-cell-icon"
};
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock(
    "div",
    {
      "data-tag": "tiny-cell",
      class: normalizeClass(["border-0 border-color-border rounded relative w-full h-7 leading-7 sm:leading-6.5 pr-5 sm:pr-7 pl-0 sm:pl-3 cursor-pointer line-clamp-1", [_ctx.m(_ctx.data ? "text-color-text-primary" : "text-color-icon-placeholder", _ctx.state.isDisplayOnly ? "pointer-events-none cursor-default text-color-text-primary pl-0" : "sm:border", _ctx.state.isDisabled ? "sm:bg-color-bg-4 cursor-not-allowed" : "")]]),
      onClick: _cache[0] || (_cache[0] = function($event) {
        return _ctx.state.isDisabled ? "" : _ctx.$emit("click", $event);
      })
    },
    [createTextVNode(
      toDisplayString(_ctx.state.isDisplayOnly ? _ctx.data || "-" : _ctx.data || _ctx.placeholder) + " ",
      1
      /* TEXT */
    ), !(_ctx.state.isDisplayOnly || _ctx.state.isDisabled) ? (openBlock(), createElementBlock("div", _hoisted_1, [renderSlot(_ctx.$slots, "icon", {}, function() {
      return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.icon), {
        class: "h-4 w-4 absolute top-1.5 sm:top-1 right-0 sm:right-2 fill-color-icon-placeholder"
      }))];
    })])) : createCommentVNode("v-if", true)],
    2
    /* CLASS */
  );
}
var Cell = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
var version = "3.22.0";
Cell.install = function(Vue) {
  Vue.component(Cell.name, Cell);
};
Cell.version = version;

export { Cell as default };

==> vue-cell-3.22.1.tgz: package/lib/index.js <==
import { t } from '@opentinyvue/vue-locale';
import { renderless, api } from '@opentinyvue/vue-renderless/cell/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { IconChevronRight } from '@opentinyvue/vue-icon';
import { openBlock, createElementBlock, normalizeClass, createTextVNode, toDisplayString, renderSlot, createBlock, resolveDynamicComponent, createCommentVNode } from 'vue';

function _createForOfIteratorHelperLoose(r, e) {
  var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"];
  if (t) return (t = t.call(r)).next.bind(t);
  if (Array.isArray(r) || (t = _unsupportedIterableToArray(r)) || e && r && "number" == typeof r.length) {
    t && (r = t);
    var o = 0;
    return function() {
      return o >= r.length ? { done: true } : { done: false, value: r[o++] };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _unsupportedIterableToArray(r, a) {
  if (r) {
    if ("string" == typeof r) return _arrayLikeToArray(r, a);
    var t = {}.toString.call(r).slice(8, -1);
    return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0;
  }
}
function _arrayLikeToArray(r, a) {
  (null == a || a > r.length) && (a = r.length);
  for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e];
  return n;
}
var _export_sfc = function _export_sfc2(sfc, props) {
  var target = sfc.__vccOpts || sfc;
  for (var _iterator = _createForOfIteratorHelperLoose(props), _step; !(_step = _iterator()).done; ) {
    var _step$value = _step.value, key = _step$value[0], val = _step$value[1];
    target[key] = val;
  }
  return target;
};

var _sfc_main = defineComponent({
  name: $prefix + "Cell",
  componentName: "Cell",
  props: {
    placeholder: {
      type: String,
      default: t("ui.cell.placeholder")
    },
    disabled: {
      type: Boolean,
      default: false
    },
    data: {
      type: String,
      default: ""
    },
    icon: {
      type: [Object, String],
      default: function _default() {
        return IconChevronRight();
      }
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var _hoisted_1 = {
  key: 0,
  "data-tag": "tiny-cell-icon"
};
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock(
    "div",
    {
      "data-tag": "tiny-cell",
      class: normalizeClass(["border-0 border-color-border rounded relative w-full h-7 leading-7 sm:leading-6.5 pr-5 sm:pr-7 pl-0 sm:pl-3 cursor-pointer line-clamp-1", [_ctx.m(_ctx.data ? "text-color-text-primary" : "text-color-icon-placeholder", _ctx.state.isDisplayOnly ? "pointer-events-none cursor-default text-color-text-primary pl-0" : "sm:border", _ctx.state.isDisabled ? "sm:bg-color-bg-4 cursor-not-allowed" : "")]]),
      onClick: _cache[0] || (_cache[0] = function($event) {
        return _ctx.state.isDisabled ? "" : _ctx.$emit("click", $event);
      })
    },
    [createTextVNode(
      toDisplayString(_ctx.state.isDisplayOnly ? _ctx.data || "-" : _ctx.data || _ctx.placeholder) + " ",
      1
      /* TEXT */
    ), !(_ctx.state.isDisplayOnly || _ctx.state.isDisabled) ? (openBlock(), createElementBlock("div", _hoisted_1, [renderSlot(_ctx.$slots, "icon", {}, function() {
      return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.icon), {
        class: "h-4 w-4 absolute top-1.5 sm:top-1 right-0 sm:right-2 fill-color-icon-placeholder"
      }))];
    })])) : createCommentVNode("v-if", true)],
    2
    /* CLASS */
  );
}
var Cell = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
var version = "3.undefined";
Cell.install = function(Vue) {
  Vue.component(Cell.name, Cell);
};
Cell.version = version;

export { Cell as default };
